@@ -372,7 +372,7 @@ class _Regressor(object, metaclass=ABCMeta):
                        outfile=None,
                        outdir=None,
                        output_type='mean',
-                       band_name=None,
+                       band_name='prediction',
                        **kwargs):
         """
         Tree variance from the RF regressor
@@ -414,6 +414,8 @@ class _Regressor(object, metaclass=ABCMeta):
                        gdal_array.NumericTypeCodeToGDALTypeCode(regressor.data.y.dtype)})
 
         defaults = regressor.get_defaults(raster=raster_obj,
+                                          output_type=output_type,
+                                          band_name=band_name,
                                           **kwargs)
 
         verbose = defaults['verbose'] if 'verbose' in defaults else False
@@ -909,7 +911,7 @@ class RFRegressor(_Regressor):
         """
 
         if min_variance is None:
-            min_variance = 0.025 * (self.data.y.max() - self.data.y.min())
+            min_variance = 0.0  # 0.025 * (self.data.y.max() - self.data.y.min())
 
         # List of index of bands to be used for regression
         if 'feature_index' in kwargs:
@@ -954,20 +956,27 @@ class RFRegressor(_Regressor):
                 return tile_arr
 
         elif output_type in ('sd', 'var'):
-
+            # Calculate variance of output across all the leaf nodes:
+            # Each leaf node may have multiple samples in it.
+            # We are trying to find standard deviation
+            # across all leaf node samples in all the trees
+            # using tree impurity statistic as we cannot access all the samples
+            # once the tree is constructed.
+            # Population variance is sum of between group variance and within group variance
+            # read http://arxiv.org/pdf/1211.0906v2.pdf
             for jj, tree_ in enumerate(self.regressor.estimators_):
                 tile_arr[jj, :] = tree_.predict(feat_arr)
 
-                var_tree = tree_.tree_.impurity[tree_.apply(feat_arr)]
+                var_tree = tree_.tree_.impurity[tree_.apply(feat_arr)]  # tree/group variance
 
                 var_tree[var_tree < min_variance] = min_variance
-                mean_tree = tree_.predict(feat_arr)
+                mean_tree = tree_.predict(feat_arr)  # tree mean
                 out_tile += var_tree + mean_tree ** 2
 
-            predictions = np.mean(tile_arr, axis=0)
+            predictions = np.mean(tile_arr, axis=0)  # population means
 
             out_tile /= len(self.regressor.estimators_)
-            out_tile -= predictions ** 2.0
+            out_tile = out_tile - predictions ** 2.0
             out_tile[out_tile < 0.0] = 0.0
 
             if output_type == 'sd':
@@ -1144,7 +1153,7 @@ class RFRegressor(_Regressor):
 
     def predict(self,
                 arr,
-                output_type=None,
+                output_type='mean',
                 **kwargs):
         """
         Calculate random forest model prediction, variance, or standard deviation.
@@ -1495,7 +1504,7 @@ class HRFRegressor(RFRegressor):
 
         # leaf variance limit for sd or var output type
         if min_variance is None:
-            min_variance = 0.025 * (self.data['labels'].max() - self.data['labels'].min())
+            min_variance = 0.0  # 0.025 * (self.data.y.max() - self.data.y.min())
 
         # define input array shape param
         if tile_end is None:
@@ -1555,7 +1564,7 @@ class HRFRegressor(RFRegressor):
                     kwargs['band_additives'][feature_index[ii]]
 
                 # initialize output array for this regressor
-                tile_arr = np.zeros([regressor.trees, tile_index[ii].shape[0]], dtype=float)
+                tile_arr = np.zeros([regressor.n_estimators, tile_index[ii].shape[0]], dtype=float)
 
                 if output_type in ('mean', 'median'):
 
@@ -1570,10 +1579,19 @@ class HRFRegressor(RFRegressor):
 
                 elif output_type in ('sd', 'var'):
 
-                    # calculate variance of output across all the leaf nodes
+                    # Calculate variance of output across all the leaf nodes:
+                    # Each leaf node may have multiple samples in it.
+                    # We are trying to find standard deviation
+                    # across all leaf node samples in all the trees
+                    # using tree impurity statistic as we cannot access all the samples
+                    # once the tree is constructed.
+                    # Population variance is sum of between group variance and within group variance
+                    # read http://arxiv.org/pdf/1211.0906v2.pdf
                     for jj, tree_ in enumerate(regressor.regressor.estimators_):
+                        # predict the tree output for the tile
                         tile_arr[jj, :] = tree_.predict(temp_arr)
 
+                        # variance in output at the leaf node of the tree
                         var_tree = tree_.tree_.impurity[tree_.apply(temp_arr)]
 
                         var_tree[var_tree < min_variance] = min_variance
